/*
 * Copyright (c) 2005-2010 KOM – Multimedia Communications Lab
 *
 * This file is part of Simonstrator.KOM.
 * 
 * Simonstrator.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


package de.tudarmstadt.maki.simonstrator.api.component.sensor.environment.data;

import de.tudarmstadt.maki.simonstrator.api.Time;
import de.tudarmstadt.maki.simonstrator.api.component.sensor.location.Location;
import de.tudarmstadt.maki.simonstrator.api.component.vehicular.roadnetwork.RoadNetworkEdge;

/**
 * @author Tobias Meuser (tobias.meuser@kom.tu-darmstadt.de)
 * @version 1.0 at 27.02.2018
 *
 */
public class VehicleProperty implements LocationBasedEnvironmentProperty {

	private final long _id;
	private final Location _location;
	private final RoadNetworkEdge _edge;
	private final double _speed;
	private long _detectionDate;
	
	public VehicleProperty(long pId, Location pLocation, RoadNetworkEdge pEdge, double pSpeed) {
		_id = pId;
		_location = pLocation;
		_edge = pEdge;
		_speed = pSpeed;
		_detectionDate = Time.getCurrentTime();
	}

	public long getId() {
		return _id;
	}

	@Override
	public long getDetectionDate() {
		return _detectionDate;
	}

	@Override
	public Location getLocation() {
		return _location;
	}

	public RoadNetworkEdge getEdge() {
		return _edge;
	}

	public double getSpeed() {
		return _speed;
	}

}
